<?php
if(!defined('ABSPATH')) exit;

/**
 * Registers all block assets so that they can be enqueued through Gutenberg in
 * the corresponding context.
 *
 * Passes translations to JavaScript.
 */
function ctw_lptools_register_block() {
	
	if( !ctw_lptools_check_wp_ver() ) {
		return;
	}

	// automatically load dependencies and version
	$asset_file = include( get_lptools_plugin_path() . 'build/index.asset.php');

	wp_register_script(
		'ctw-lptools',
		get_lptools_plugin_url(). 'build/index.js',
		$asset_file['dependencies'],
		$asset_file['version']
	);

	wp_register_style(
		'ctw-lptools',
		get_lptools_plugin_url().'css/style.css',
		array( ),
		filemtime( get_lptools_plugin_path() . 'css/style.css' )
	);

	wp_register_style(
		'ctw-lptools-editor',
		get_lptools_plugin_url().'css/style-editor.css',
		array( 'wp-edit-blocks' ),
		filemtime( get_lptools_plugin_path() . 'css/style-editor.css' )
	);
	
	register_block_type( 'ctw-lptools/lptools', array(
		'editor_script' => 'ctw-lptools',
	) );
	
	// コアブロックのパターンを除去
	remove_theme_support( 'core-block-patterns' );
	add_theme_support( 'responsive-embeds' );
	
	// カラーピッカー初期化
	wp_enqueue_style( 'wp-color-picker' );
    wp_enqueue_script( array( 'jquery', 'wp-color-picker') );
		
}
add_action( 'init', 'ctw_lptools_register_block', 9999 );



// --------------------------------------------
// ブロックカテゴリーの登録
// --------------------------------------------
function ctw_lptools_add_new_block_category( $block_categories ) {
	array_unshift(
		$block_categories,
		array(
			'slug'  => 'ctw-lptools-header-layout',
			'title' => '[CTW]ファーストビュー',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-footer',
			'title' => '[CTW]フッター',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-cta',
			'title' => '[CTW]CTA（ボタン・オプトインフォーム）',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-subhead',
			'title' => '[CTW]見出し',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-box-section',
			'title' => '[CTW]ボックス・セクション',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-bullet',
			'title' => '[CTW]ブレット',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-profile',
			'title' => '[CTW]プロフィール',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-recommend',
			'title' => '[CTW]お客様の声・推薦',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-numbering',
			'title' => '[CTW]ナンバリング',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-faq',
			'title' => '[CTW]よくある質問',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-others',
			'title' => '[CTW]その他',
			'icon'  => null,
		),
		array(
			'slug'  => 'ctw-lptools-parts',
			'title' => '[CTW]パーツ',
			'icon'  => null,
		)
	);
	return $block_categories;
}



// --------------------------------------------
// カラーパレット
// --------------------------------------------
function ctwlpt_color_set(){
	
	$post_id	= ( isset( $_GET['post'] ) ) ? $_GET['post'] : null;
	$post_type	= ( isset( $_GET['post_type'] ) ) ? $_GET['post_type'] : null;
	$slug = '';
	
	if( isset($post_id) ) {
		$slug = get_page_template_slug( $post_id );
		$post_type = get_post_type( $post_id );
	}
	
	if( ('clp' != $post_type && 'lptools_template' != $post_type) && $slug != CTW_LPTOOLS_TEMPLATE_SLUG ) {
		return;
	}

	$custom_palette = array(
		array(
			'name'	=> __('Black') ,
			'slug'	=> 'ctwlpt-black',
			'color'	=> '#000',
		) ,
		array(
			'name' => __('Dark') ,
			'slug'	=> 'ctwlpt-dark',
			'color' => '#333',
		) ,
		array(
			'name' => __('Medium gray') ,
			'slug'	=> 'ctwlpt-medium-gray',
			'color' => '#999',
		) ,
		array(
			'name' => __('gray') ,
			'slug'	=> 'ctwlpt-light-gray',
			'color' => '#ccc',
		) ,
		array(
			'name' => __('White','White') ,
			'slug'	=> 'ctwlpt-white',
			'color' => '#FFF',
		) ,
		array(
			'name' => __('Light gray') ,
			'slug'	=> 'ctwlpt-light-gray',
			'color' => '#55638c',
		) ,
		array(
			'name' => __('Red') ,
			'slug'	=> 'ctwlpt-red',
			'color' => '#e22024',
		) ,
		array(
			'name' => __('Dark red') ,
			'slug'	=> 'ctwlpt-dark-red',
			'color' => '#a8171b',
		) ,
		array(
			'name' => __('Blue') ,
			'slug'	=> 'ctwlpt-blue',
			'color' => '#128ee8',
		) ,
		array(
			'name' => __('Dark blue') ,
			'slug'	=> 'ctwlpt-dark-blue',
			'color' => '#1e477d',
		) ,
		array(
			'name' => __('Emerald') ,
			'slug'	=> 'ctwlpt-emerald',
			'color' => '#3dcb92',
		),
		array(
			'name' => __('Green') ,
			'slug'	=> 'ctwlpt-green',
			'color' => '#12ae1e',
		),
		array(
			'name' => __('Dark green') ,
			'slug'	=> 'ctwlpt-dark-green',
			'color' => '#0c7815',
		),
		array(
			'name' => __('Orange') ,
			'slug'	=> 'ctwlpt-orange',
			'color' => '#ff8a00',
		),
		array(
			'name' => __('Purple') ,
			'slug'	=> 'ctwlpt-purple',
			'color' => '#9b51e0',
		),
		array(
			'name' => __('Vivid Pink') ,
			'slug'	=> 'ctwlpt-vivid-pink',
			'color' => '#f817a6',
		),
		array(
			'name' => __('Pink') ,
			'slug'	=> 'ctwlpt-pink',
			'color' => '#ff7ea9',
		),
		array(
			'name' => __('Light Yellow') ,
			'slug'	=> 'ctwlpt-light-yellow',
			'color' => '#fff100',
		),
		array(
			'name' => __('Yellow') ,
			'slug'	=> 'ctwlpt-yellow',
			'color' => '#ffe000',
		)
	);

	$palette = get_theme_support( 'editor-color-palette' );
	if ( ! empty( $palette ) ) {
		$palette = array_merge( $palette[0], $custom_palette);
	} else {
		$palette = $custom_palette;   
	}
	
	add_theme_support( 'editor-color-palette', $palette );
}

function ctwlpt_custom_color_set() {
	
	$post_id = ( isset( $_GET['post'] ) ) ? $_GET['post'] : null;
	if ( $post_id === null ) return;

	$custom_palette_key = get_post_meta( $post_id,'ctwlpt_color_palette', true );
	if ( $custom_palette_key === '' ) return;

	$custom_palette = array();
	$color_palettes = get_option( 'lptools_color_palettes' )[$custom_palette_key];
	foreach ( $color_palettes as $i => $color ) {
		if ( empty( $color ) ) continue;
		$custom_palette[] = array(
			'name'	=> '',
			'slug'	=> "ctwlpt-color-{$i}",
			'color'	=> $color,
		);
	}
	
	// デフォルトのパレットを活かす場合、コメントアウトを外す
/*
	$palette = get_theme_support( 'editor-color-palette' );
	if ( !empty( $palette ) ) {
		$palette = array_merge( $palette[0], $custom_palette);
	} else {
		$palette = $custom_palette;
	}
*/
	
	// デフォルトのパレットを活かさない場合
	$palette = array_merge( $custom_palette, array(
		array(
			'name'	=> __('Black') ,
			'slug'	=> 'ctwlpt-black',
			'color'	=> '#000',
		) ,
		array(
			'name' => __('Dark') ,
			'slug'	=> 'ctwlpt-dark',
			'color' => '#333',
		) ,
		array(
			'name' => __('Medium gray') ,
			'slug'	=> 'ctwlpt-medium-gray',
			'color' => '#999',
		) ,
		array(
			'name' => __('gray') ,
			'slug'	=> 'ctwlpt-light-gray',
			'color' => '#ccc',
		) ,
		array(
			'name' => __('White') ,
			'slug'	=> 'ctwlpt-white',
			'color' => '#FFF',
		)
	));
	//$palette = $custom_palette;

	add_theme_support( 'editor-color-palette', $palette );
}

// --------------------------------------------
// ブロック名を返す
// --------------------------------------------
function get_ctwlpt_block_name() {
	$ctwlpt_blocks = array(
		'ctwlpt-block/bg-video-wrap',
		'ctwlpt-block/faq-01',
		'ctwlpt-block/faq',
		'ctwlpt-block/subhead-h2',
		'ctwlpt-block/subhead-h3',
		'ctwlpt-block/subhead-h2img',
		'ctwlpt-block/footer-01',
		'ctwlpt-block/bullet-01',
		'ctwlpt-block/bullet-02',
		'ctwlpt-block/float-section',
		'ctwlpt-block/moneyback-01',
		'ctwlpt-block/voice-04',
		'ctwlpt-block/voice-03',
		'ctwlpt-block/voice-02',
		'ctwlpt-block/voice-01',
		'ctwlpt-block/fs-h1',
		'ctwlpt-block/fs-h2',
		'ctwlpt-block/fs-h3',
		'ctwlpt-block/firstview-01',
		'ctwlpt-block/firstview-02',
		'ctwlpt-block/firstview-03',
		'ctwlpt-block/firstview-04',
		'ctwlpt-block/firstview-05',
		'ctwlpt-block/firstview-06',
		'ctwlpt-block/firstview-07',
		'ctwlpt-block/arrow',
		'ctwlpt-block/iframe-yt',
		'ctwlpt-block/cta-a-01',
		'ctwlpt-block/cta-01',
		'ctwlpt-block/cta-02',
		'ctwlpt-block/cta-03',
		'ctwlpt-block/cta-04',
		'ctwlpt-block/cta-mc-01',
		'ctwlpt-block/cta-mc-02',
		'ctwlpt-block/cta-a-01',
		'ctwlpt-block/cta-attention',
		'ctwlpt-block/section',
		'ctwlpt-block/numbering-01',
		'ctwlpt-block/numbering-02',
		'ctwlpt-block/numbering-03',
		'ctwlpt-block/numbering-content-01',
		'ctwlpt-block/numbering-content-02',
		'ctwlpt-block/numbering-content-03',
		'ctwlpt-block/profile-01',
		'ctwlpt-block/profile-02',
		'ctwlpt-block/timer',
		'ctwlpt-block/table-01',
		'ctwlpt-block/ps-01',
	);
	
	return $ctwlpt_blocks;
}


// --------------------------------------------
// LPtoolsの利用範囲（通常の投稿でLPtoolsのブロックを利用できるようにするかどうか）
// --------------------------------------------
function ctwlpt_block_blacklists( $allowed_block_types, $block_editor_context ) {
	global $post_type;

	if( ('clp' != $post_type && 'lptools_template' != $post_type) && get_option('lptools_use_post') != 1 ) {
		$default_blocks = array();
		$blocks = WP_Block_Type_Registry::get_instance()->get_all_registered();
		foreach ( $blocks as $block ) {
			$default_blocks[] = $block->name;
		}
		$unregister_blocks = get_ctwlpt_block_name();
		$allowed_block_types = array_values( array_diff( $default_blocks, $unregister_blocks ) );
		return $allowed_block_types;
	} else {
		return ;
	}
}


// --------------------------------------------
// 通常の投稿でLPtoolsを利用する場合のファイル読み込み
// --------------------------------------------
function ctwlpt_enqueue_style_in_post() {
	global $post_type;
	if( ('clp' != $post_type && 'lptools_template' != $post_type) && get_option('lptools_use_post') == 1 ) {
		wp_enqueue_style( 'ctw-lptools' );
	}
}
//add_action('wp_footer', 'ctwlpt_enqueue_style_in_post');


// --------------------------------------------
// LPtools以外のブロックについて（LPを作るとき、LPtools以外のブロックも利用する）
// --------------------------------------------
function ctwlpt_block_whitelists( $allowed_block_types, $block_editor_context ) {
	
	global $post_type;
	global $post;
	if( isset($post->ID) ) { $slug = get_page_template_slug( $post->ID ); }
	
	if( ( 'clp' == $post_type || 'lptools_template' == $post_type || ( 'page' == $post_type && $slug == CTW_LPTOOLS_TEMPLATE_SLUG ) ) && get_option('lptools_use_other_blocks') != 1 ) {
		$default_blocks = array(
			// テキスト
			'core/paragraph',    // 段落
			'core/heading',      // 見出し
			'core/list',         // リスト
			'core/quote',        // 引用
			'core/code',         // コード
			'core/freeform',     // クラシック
			'core/preformatted', // 整形済み
			'core/pullquote',    // プルクオート
			'core/table',        // テーブル
			'core/verse',        // 詩
			
			// メディア
			'core/image',      // 画像
			'core/gallery',    // ギャラリー
			'core/audio',      // 音声
			'core/cover',      // カバー
			'core/file',       // ファイル
			'core/media-text', // メディアとテキスト
			'core/video',      // 動画
			
			// デザイン
			'core/buttons',      // ボタン
			'core/columns',      // カラム
			'core/group',        // グループ
			//'core/more',         // 続き
			//'core/nextpage',     // ページ区切り
			'core/separator',    // 区切り
			'core/spacer',       // スペーサー
			//'core/site-logo',    // サイトロゴ
			//'core/site-tagline', // サイトのキャッチフレーズ
			//'core/site-title',   // サイトのタイトル
			//'core/query-title',  // アーカイブタイトル
			//'core/post-terms',   // 投稿カテゴリー, 投稿タグ
			
			// ウィジェット
			'core/shortcode',       // ショートコード
			//'core/archives',        // アーカイブ
			//'core/calendar',        // カレンダー
			//'core/categories',      // カテゴリー
			'core/html',            // カスタムHTML
			//'core/latest-comments', // 最新のコメント
			//'core/latest-posts',    // 最新の投稿
			//'core/page-list',       // 固定ページリスト
			//'core/rss',             // RSS
			//'core/social-links',    // ソーシャルアイコン
			//'core/tag-cloud',       // タグクラウド
			//'core/search',          // 検索
			
			// テーマ
			//'core/query',               // クエリーループ, 投稿一覧
			//'core/post-title',          // 投稿タイトル
			//'core/post-content',        // 投稿コンテンツ
			//'core/post-date',           // 投稿日
			//'core/post-excerpt',        // 投稿の抜粋
			//'core/post-featured-image', // 投稿のアイキャッチ画像
			//'core/loginout',            // ログイン/ログアウト
			
			// 埋め込み
			'core/embed',
		);
		
		$ctwlpt_blocks = get_ctwlpt_block_name();
		
		$allowed_block_types = array_merge($default_blocks,$ctwlpt_blocks);
	}
	
	return $allowed_block_types;
}
if( ctw_lptools_check_wp_ver() && is_admin() ) {
	//add_filter( 'allowed_block_types_all', 'ctwlpt_block_blacklists', 9999, 2 );
	add_action( 'after_setup_theme', 'ctwlpt_color_set',9999 );
	add_filter( 'block_categories_all', 'ctw_lptools_add_new_block_category', 10, 2 );
	add_filter( 'allowed_block_types_all', 'ctwlpt_block_whitelists', 9999, 2 );
	add_action( 'admin_init', 'ctwlpt_custom_color_set' );
}


// --------------------------------------------
// カスタムカラーパレットのデフォルト設定を返すだけ
// --------------------------------------------
function ctwlpt_color_titles_default() {
	return array(
		'ビジネス・セミナー・説明会',
		'セールスレター',
		'女性向け１',
		'女性向け２',
		'男性向け',
		'シニア向け',
		'士業向け（弁護士・会計士・税理士等）',
		'健康・ヘルス',
		'エレガント・高級感のある',
		'ポップ・明るい・楽しい'
	);
}
function ctwlpt_colors_default() {
	return array(
		array(
			'#2063a1',
			'#3277ae',
			'#698ead',
			'#ffee00',
			'#dd0d1e',
			'#0a0a0a',
			'#eef2f5',
			'',
			'',
			'',
		),
		array(
			'#e7e7e7',
			'#333333',
			'#a8171b',
			'#1d699b',
			'#ff9b3a',
			'',
			'',
			'',
			'',
			'',
		),
		array(
			'#f08984',
			'#f5f1ee',
			'#c9bcac',
			'#efd2ca',
			'#fbf8f5',
			'#848484',
			'#ffffff',
			'#90a5a8',
			'#c5dde3',
			'',
		),
		array(
			'#b59da1',
			'#f9f4f4',
			'#e5d8da',
			'#e7dfd6',
			'#af9f8d',
			'',
			'',
			'',
			'',
			'',
		),
		array(
			'#000000',
			'#254654',
			'#303030',
			'#e0e0e0',
			'#ffffff',
			'#b60a1a',
			'#154177',
			'#99834d',
			'',
			'',
		),
		array(
			'#793a57',
			'#4d3339',
			'#8c873e',
			'#d1c5a5',
			'#a38a5f',
			'',
			'',
			'',
			'',
			'',
		),
		array(
			'#2472bf',
			'#113f87',
			'#f1f8fe',
			'#f9891b',
			'#333333',
			'#ffffff',
			'',
			'',
			'',
			'',
		),
		array(
			'#20663f',
			'#249959',
			'#abd408',
			'#ffd412',
			'#ff821c',
			'',
			'',
			'',
			'',
			'',
		),
		array(
			'#28292c',
			'#827566',
			'#c0af82',
			'#8e1c1c',
			'#0c4666',
			'#0f4f12',
			'',
			'',
			'',
			'',
		),
		array(
			'#f26b7a',
			'#f0f2dc',
			'#d9ea52',
			'#8ac7de',
			'#87796f',
			'',
			'',
			'',
			'',
			'',
		)
	);
}
