<?php
if(!defined('ABSPATH')) exit;

// --------------------------------------------
// LP用のカスタム投稿追加
// --------------------------------------------
function lptools_landingpage_post_type() {
	register_post_type( 'clp',
		array(
			'label' => 'LPを作る',
			'labels' => array(
				'all_items' => 'ランディングページ 一覧'
			),
			'public' => true, 
			'has_archive' => true,
			'menu_position' => 5,
			'show_in_rest'	=> true,
			'supports' => array(
				'title',
				'editor'
			)
		)
	);
	
	register_taxonomy( 'clp_category', 'clp', array(
		'label'		=> '用途分類',
        'show_ui'	=> true,
        'rewrite'	=> true,
        'hierarchical'	=> true,
        'singular_label' => '用途分類'
	) );
	
	register_post_type( 'lptools_template',
		array(
			'label' => 'テンプレートを作る',
			'labels' => array(
				'all_items' => 'テンプレート 一覧'
			),
			'public' => true, 
			'has_archive' => true,
			'menu_position' => 5,
			'show_in_rest'	=> true,
			'supports' => array(
				'title',
				'editor',
				'thumbnail'
			)
		)
	);
	
/*
	register_taxonomy( 'lptools_template_category', 'lptools_template', array(
		'label'		=> 'カテゴリー',
        'show_ui'	=> true,
        'rewrite'	=> true,
        'hierarchical'	=> true,
        'singular_label' => 'カテゴリー'
	) );
*/
}
add_action( 'init', 'lptools_landingpage_post_type' );


// --------------------------------------------
// テンプレートファイルを指定する
// --------------------------------------------
function lptools_clp_template($template){
	global $wp_query;
	if( $wp_query->query_vars['post_type'] == 'clp' || $wp_query->query_vars['post_type'] == 'lptools_template' ){
		$template = get_lptools_plugin_path().'template/lptools_lp.php';
	}
	return $template;
}
add_filter( 'single_template', 'lptools_clp_template' );


// --------------------------------------------
// 設定カスタムフィールド追加
// --------------------------------------------
function lptools_timer_add_custom_fields() {
	add_meta_box(
		'lptools_timer_setting',
		'【LPtools】タイマー設定',
		'lptools_timer_custom_fields',
		array('clp','page'),
		'normal'
	);
}
add_action('admin_menu', 'lptools_timer_add_custom_fields');

function lptools_optional_add_custom_fields() {
	add_meta_box(
		'lptools_optional_setting',
		'【LPtools】オプション設定',
		'lptools_optional_custom_fields',
		array('clp','page'),
		'normal'
	);
}
add_action('admin_menu', 'lptools_optional_add_custom_fields');

function lptools_redirect_add_custom_fields() {
	add_meta_box(
		'lptools_redirect_setting',
		'【LPtools】リダイレクト設定',
		'lptools_redirect_custom_fields',
		array('clp','page'),
		'normal'
	);
}
add_action('admin_menu', 'lptools_redirect_add_custom_fields');

function lptools_ogp_add_custom_fields() {
	add_meta_box(
		'lptools_ogp_setting',
		'【LPtools】OGP設定',
		'lptools_ogp_custom_fields',
		array('clp','page'),
		'normal'
	);
}
add_action('admin_menu', 'lptools_ogp_add_custom_fields');

function lptools_footer_button_add_custom_fields() {
	add_meta_box(
		'lptools_footer_button_setting',
		'【LPtools】フッターボタン設定',
		'lptools_footer_button_custom_fields',
		array('clp','page'),
		'normal'
	);
}
add_action('admin_menu', 'lptools_footer_button_add_custom_fields');

function lptools_color_palette_add_custom_fields() {
	add_meta_box(
		'lptools_color_palette_setting',
		'【LPtools】カラーパレット設定',
		'lptools_color_palette_custom_fields',
		array('clp','page','lptools_template'),
		'normal'
	);
}
add_action('admin_menu', 'lptools_color_palette_add_custom_fields');

function lptools_remove_custom_fields() {
	global $post_type;
	global $post;
	if( $post ) {
		$slug = get_page_template_slug( $post->ID );
		if ( 'page' == $post_type && $slug != CTW_LPTOOLS_TEMPLATE_SLUG ) {
			remove_meta_box( 'lptools_timer_setting', 'page', 'normal' );
			remove_meta_box( 'lptools_optional_setting', 'page', 'normal' );
			remove_meta_box( 'lptools_footer_button_setting', 'page', 'normal' );
		}
	}
}
add_action('admin_head', 'lptools_remove_custom_fields');

// --------------------------------------------
// 設定カスタムフィールドの入力エリア
// --------------------------------------------
function lptools_timer_custom_fields() {
	global $post;
	
	$ctwlpt_use_timer_triger	= get_post_meta( $post->ID,'ctwlpt_use_timer_triger', true );
	if( empty($ctwlpt_use_timer_triger) ) $ctwlpt_use_timer_triger = 'no';
	
	$ctwlpt_timer_trigger_key	= get_post_meta( $post->ID,'ctwlpt_timer_trigger_key', true );
	if( empty($ctwlpt_timer_trigger_key) ) $ctwlpt_timer_trigger_key = '';
	
	$ctwlpt_timer_trigger_read_key	= get_post_meta( $post->ID,'ctwlpt_timer_trigger_read_key', true );
	if( empty($ctwlpt_timer_trigger_read_key) ) $ctwlpt_timer_trigger_read_key = $ctwlpt_timer_trigger_key;
	
	$ctwlpt_timer_trigger_day	= get_post_meta( $post->ID,'ctwlpt_timer_trigger_day', true );
	if( empty($ctwlpt_timer_trigger_day) ) $ctwlpt_timer_trigger_day = '';
	
	$ctwlpt_timer_trigger_hour	= get_post_meta( $post->ID,'ctwlpt_timer_trigger_hour', true );
	if( empty($ctwlpt_timer_trigger_hour) ) $ctwlpt_timer_trigger_hour = '';
	
	$ctwlpt_timer_trigger_min	= get_post_meta( $post->ID,'ctwlpt_timer_trigger_min', true );
	if( empty($ctwlpt_timer_trigger_min) ) $ctwlpt_timer_trigger_min = '';
	
	$ctwlpt_timer_trigger_expire	= get_post_meta( $post->ID,'ctwlpt_timer_trigger_expire', true );
	if( empty($ctwlpt_timer_trigger_expire) ) $ctwlpt_timer_trigger_expire = 30;
	
	$ctwlpt_timer_type	= get_post_meta( $post->ID,'ctwlpt_timer_type', true );
	if( empty($ctwlpt_timer_type) ) $ctwlpt_timer_type = 'no';
	
	$ctwlpt_timer_access_times	= get_post_meta( $post->ID,'ctwlpt_timer_access_times', true );
	if( empty($ctwlpt_timer_access_times) ) $ctwlpt_timer_access_times = '1';
	
	$ctwlpt_timer_redirect_url	= get_post_meta( $post->ID,'ctwlpt_timer_redirect_url', true );
	
	$ctwlpt_timer_end_word	= get_post_meta( $post->ID,'ctwlpt_timer_end_word', true );
	if( empty($ctwlpt_timer_end_word) ) $ctwlpt_timer_end_word = '終了しました';
	
	$ctwlpt_timer_use_s	= get_post_meta( $post->ID,'ctwlpt_timer_use_s', true );
	if( empty($ctwlpt_timer_use_s) ) $ctwlpt_timer_use_s = 'yes';
	
	$ctwlpt_timer_use_ms	= get_post_meta( $post->ID,'ctwlpt_timer_use_ms', true );
	if( empty($ctwlpt_timer_use_ms) ) $ctwlpt_timer_use_ms = 'no';
	
	$ctwlpt_timer_countdown_date	= get_post_meta( $post->ID,'ctwlpt_timer_countdown_date', true );
	
	$ctwlpt_timer_limited_time		= get_post_meta( $post->ID,'ctwlpt_timer_limited_time', true );
	if( empty($ctwlpt_timer_limited_time) ) $ctwlpt_timer_limited_time = '1';
?>
	<style type="text/css" media="screen">
		tr {
			border-bottom: 1px dotted #ccc;
		}
		.t-h,.t-b {
			padding: 2em 1em;
		}
		.t-h {
			vertical-align: top;
			width: 40%;
			font-weight: bold;
		}
		.t-b {
			width: 60%;
		}
		.t-b p:last-child {
			margin-bottom: 0;
		}
	</style>
	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css" type="text/css" media="all" />
	<link rel="stylesheet" href="https://npmcdn.com/flatpickr/dist/themes/dark.css" type="text/css" media="all" />
	<script src="https://cdn.jsdelivr.net/npm/flatpickr" type="text/javascript"></script>
	<script src="https://cdn.jsdelivr.net/npm/flatpickr/dist/l10n/ja.js"></script>
	<script defer src="https://use.fontawesome.com/releases/v5.15.4/js/all.js" crossorigin="anonymous"></script>
	<script type="text/javascript">
		jQuery(document).ready(function($){
			var config = {'locale': 'ja',enableTime: true,dateFormat: "Y/m/d H:i:S",}
			$('#ctwlpt_timer_countdown_date').flatpickr(config);
		});

/*
		jQuery(document).ready(function($){
			selected_use_type_check();
			
			$('.ctwlpt_timer_type,.ctwlpt_use_timer_triger').on('click',function() {
				selected_use_type_check();
			});
			
			function selected_use_type_check(){
				var lpt_timer_type = $('.ctwlpt_timer_type:checked').val();
				if ( lpt_timer_type == 'countdown' ) {
					$('.ctwlpt_timer_select_countdown').fadeIn();
					$('.ctwlpt_timer_select_limited').fadeOut();
					$('.ctwlpt_timer_select_trigger').fadeOut();
					$('.ctwlpt_select_nouse_timer_triger').fadeIn();
				} else if ( lpt_timer_type == 'limited' ) {
					$('.ctwlpt_timer_select_limited').fadeIn();
					$('.ctwlpt_timer_select_countdown').fadeOut();
					$('.ctwlpt_timer_select_trigger').fadeOut();
					$('.ctwlpt_select_nouse_timer_triger').fadeIn();
				} else if ( lpt_timer_type == 'trigger' ) {
					$('.ctwlpt_timer_select_limited').fadeOut();
					$('.ctwlpt_timer_select_countdown').fadeOut();
					$('.ctwlpt_timer_select_trigger').fadeIn();
					$('.ctwlpt_select_nouse_timer_triger').fadeOut();
					$('#ctwlpt_use_timer_triger_2').prop('checked', true);
				} else {
					$('.ctwlpt_timer_select_countdown').fadeOut();
					$('.ctwlpt_timer_select_limited').fadeOut();
					$('.ctwlpt_timer_select_trigger').fadeOut();
					$('.ctwlpt_select_nouse_timer_triger').fadeIn();
				}
				
				var lpt_use_timer_trigger = $('.ctwlpt_use_timer_triger:checked').val();
				if ( lpt_use_timer_trigger == 'yes' || lpt_timer_type == 'trigger' ) {
					$('.ctwlpt_select_use_timer_triger').fadeIn();
				} else {
					$('.ctwlpt_select_use_timer_triger').fadeOut();
				}
			}
		});
*/
		
		// アコーディオン
		jQuery(function($) {
			//$(".is-style-ctwlpt-block-faq-03 .ctwlpt-block-faq-dt").next().addClass('ctwlpt-block-faq-dd-hide');
			$(".is-style-ctwlpt-block-faq-03 .ctwlpt-block-faq-dt").on('click',function(){
				$(this).toggleClass('ctwlpt-block-faq-dt-icon-minus');
				$(this).next().slideToggle();
			});
		});
		
		// テーブル
		jQuery(function($) {
			$('.ctwlpt-block-table-content').hover(function() {
				$(this).children('.ctwlpt-block-table-fixed-attention').fadeOut(1000);
			});
		});
		
	</script>
	
	<h2 style="padding:.5em;color:#fff;background:#666;border-radius:5px 5px 0px 0px;">【STEP 1】タイマータイプ選択</h2>
	<div style="padding:1em;border:1px solid #666;border-radius:0px 0px 5px 5px;">
		<table class="lptools-setting-table" style="width:100%">
			<tr>
				<td class="t-h">
					タイマータイプ
					<div style="padding:1em;margin-top:1em;background:#eee;">利用したいタイマーのタイプを選択します。<br />タイプを選択したら、STEP 2へ進みます。<br />STEP 2では、STEP 1で選択したタイマータイプの設定をします。</div>
				</td>
				<td class="t-b">
					<p class="timer-type-select"><input type="radio" name="ctwlpt_timer_type" value="no" id="ctwlpt_timer_type_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_timer_type,'no') ?>/> <label for="ctwlpt_timer_type_1">タイマーを利用しない</label></p>
					
					<p class="timer-type-select timer-type-select-onetime"><input type="radio" name="ctwlpt_timer_type" value="onetime" id="ctwlpt_timer_type_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_timer_type,'onetime') ?>/> <label for="ctwlpt_timer_type_2">ワンタイム（決められた回数しかアクセスできない）</label></p>
					
					<p class="timer-type-select timer-type-select-cd"><input type="radio" name="ctwlpt_timer_type" value="countdown" id="ctwlpt_timer_type_3" class="ctwlpt_timer_type" <?php checked($ctwlpt_timer_type,'countdown') ?>/> <label for="ctwlpt_timer_type_3">カウントダウン（指定日時で終了）</label></p>
					
					<p class="timer-type-select timer-type-select-limited"><input type="radio" name="ctwlpt_timer_type" value="limited" id="ctwlpt_timer_type_4" class="ctwlpt_timer_type" <?php checked($ctwlpt_timer_type,'limited') ?>/> <label for="ctwlpt_timer_type_4">リミテッド（アクセスから◯時間）</label></p>
					
					<p class="timer-type-select timer-type-select-step"><input type="radio" name="ctwlpt_timer_type" value="trigger" id="ctwlpt_timer_type_5" class="ctwlpt_timer_type" <?php checked($ctwlpt_timer_type,'trigger') ?>/> <label for="ctwlpt_timer_type_5">ステップメール連動（起点となるページのアクセスから◯日後の◯時◯分）</label></p>
					
					
					<div class="ctwlpt_timer_select_trigger" style="padding:1em;border:dotted 1px #c00;">
						<p style="font-weight:bold">※ステップメール連動タイマーは上級者向けの機能となります。</p>
						
						<p>ステップメール連動タイマーを利用するとき、タイマーを表示するページとは別に、タイマーの起点とするページの用意が必要です。</p>
						<p>オプトページのサンクスページなど、ユーザーが登録後にアクセスをするページをタイマーの起点としてください。</p>
						<p>詳しい使い方は<a href="https://ctw-contents.com/ctp/lptools/member/faq/3595/">こちら</a>をご覧ください。</p>
					</div>
				</td>
			</tr>
		</table>
	</div>
	
	<h2 style="margin-top:1em;padding:.5em;background:#ffc93b;border-radius:5px 5px 0px 0px;">【STEP 2】ワンタイム選択時の設定</h2>
	<div style="padding:1em;border:1px solid #ffc93b;border-radius:0px 0px 5px 5px;">
		<table class="lptools-setting-table" style="width:100%">
			<tr class="ctwlpt_timer_select_onetime">
				<td class="t-h">アクセス可能回数</td>
				<td class="t-b">
					<p><input type="number" min="1" max="99" name="ctwlpt_timer_access_times" id="ctwlpt_timer_access_times" value="<?php echo $ctwlpt_timer_access_times; ?>" /> 回</p>
				</td>
			</tr>
		</table>
	</div>
	
	<h2 style="margin-top:1em;padding:.5em;color:#fff;background:#ff3b43;border-radius:5px 5px 0px 0px;">【STEP 2】カウントダウン選択時の設定</h2>
	<div style="padding:1em;border:1px solid #ff3b43;border-radius:0px 0px 5px 5px;">
		<table class="lptools-setting-table" style="width:100%">
			<tr class="ctwlpt_timer_select_countdown">
				<td class="t-h">カウントダウン終了日時</td>
				<td class="t-b">
					<p><input type="text" name="ctwlpt_timer_countdown_date" id="ctwlpt_timer_countdown_date" style="max-width:400px;" value="<?php echo $ctwlpt_timer_countdown_date; ?>" data-mindate=today /></p>
					<p>例：2022/01/01 19:00:00</p>
				</td>
			</tr>
		</table>
	</div>
	
	<h2 style="margin-top:1em;padding:.5em;color:#fff;background:#347bff;border-radius:5px 5px 0px 0px;">【STEP 2】リミテッド選択時の設定</h2>
	<div style="padding:1em;border:1px solid #347bff;border-radius:0px 0px 5px 5px;">
		<table class="lptools-setting-table" style="width:100%">
			<tr class="ctwlpt_timer_select_limited">
				<td class="t-h">アクセスからの有効時間</td>
				<td class="t-b">
					<p><input type="number" min="1" max="24" name="ctwlpt_timer_limited_time" id="ctwlpt_timer_limited_time" value="<?php echo $ctwlpt_timer_limited_time; ?>" /> 時間</p>
				</td>
			</tr>
		</table>
	</div>
	
	<h2 style="margin-top:1em;padding:.5em;color:#fff;background:#23ce50;border-radius:5px 5px 0px 0px;">【STEP 2】ステップメール連動選択時の設定</h2>
	<div style="padding:1em;border:1px solid #23ce50;border-radius:0px 0px 5px 5px;">
		<table class="lptools-setting-table" style="width:100%">
			<tr class="ctwlpt_timer_select_trigger">
				<td class="t-h">
					ステップメール連動タイマーの期限
					<div style="padding:1em;margin-top:1em;background:#eee;">ユーザー側でCookieが削除されたり、異なるブラウザ・デバイスの場合は起点となる日時が読み取れないため、予備の期限を設定してください。<br />詳しい使い方は<a href="https://ctw-contents.com/ctp/lptools/member/faq/3595/">こちら</a>をご覧ください。</div>
				</td>
				<td class="t-b">
					<p>起点となる日時から...<br /><input type="number" min="0" max="99" maxlength="2" name="ctwlpt_timer_trigger_day" id="ctwlpt_timer_trigger_day" value="<?php echo $ctwlpt_timer_trigger_day; ?>" style="max-width:4em"/>日後の<input type="number" min="0" max="24" maxlength="2" name="ctwlpt_timer_trigger_hour" id="ctwlpt_timer_trigger_hour" value="<?php echo $ctwlpt_timer_trigger_hour; ?>" style="max-width:4em"/>時<input type="number" min="0" max="59" maxlength="2" name="ctwlpt_timer_trigger_min" id="ctwlpt_timer_trigger_min" value="<?php echo $ctwlpt_timer_trigger_min; ?>" style="max-width:4em"/>分まで</p>
					<p>例：起点となる日時（起点ページへの最初のアクセス日時）が2022/01/01で、本設定を「10」日後「19」時「00」分に設定した場合、期限は2022/01/11 19:00になります。</p>
					<p>注：起点となる日時（起点ページへの最初のアクセス日時）がCookieにないときのために、URLのパラメータで期限を指定する必要があります。詳しい使い方は<a href="https://ctw-contents.com/ctp/lptools/member/faq/3595/">こちら</a>をご覧ください。</p>
					<p>読み込むアクセスのID：<input type="text" pattern="^[0-9A-Za-z]+$" name="ctwlpt_timer_trigger_read_key" id="ctwlpt_timer_trigger_read_key" value="<?php echo $ctwlpt_timer_trigger_read_key; ?>" placeholder="例：lptools_step_01"/></p>
				</td>
			</tr>
		</table>
	</div>
	
	<h2 style="margin-top:1em;padding:.5em;color:#fff;background:#666;border-radius:5px 5px 0px 0px;">【STEP 3】タイマー共通設定</h2>
	<div style="padding:1em;border:1px solid #666;border-radius:0px 0px 5px 5px;">
		<table class="lptools-setting-table" style="width:100%">
			<tr>
				<td class="t-h">タイマー終了時の転送先URL</td>
				<td class="t-b">
					<p><input type="text" name="ctwlpt_timer_redirect_url" id="ctwlpt_timer_redirect_url" value="<?php echo $ctwlpt_timer_redirect_url; ?>" /></p>
				</td>
			</tr>
			
			<tr>
				<td class="t-h">タイマー終了時の表示メッセージ</td>
				<td class="t-b">
					<p><input type="text" name="ctwlpt_timer_end_word" id="ctwlpt_timer_end_word" value="<?php echo $ctwlpt_timer_end_word; ?>" /></p>
				</td>
			</tr>
			
			<tr>
				<td class="t-h">秒単位の表示</td>
				<td class="t-b">
					<p><input type="radio" name="ctwlpt_timer_use_s" value="yes" id="ctwlpt_timer_use_s_1" <?php checked($ctwlpt_timer_use_s,'yes') ?>/> <label for="ctwlpt_timer_use_s_1">表示する</label></p>
					<p><input type="radio" name="ctwlpt_timer_use_s" value="no" id="ctwlpt_timer_use_s_2" <?php checked($ctwlpt_timer_use_s,'no') ?>/> <label for="ctwlpt_timer_use_s_2">表示しない</label></p>
				</td>
			</tr>
			
			<tr>
				<td class="t-h">1/1000秒単位の表示</td>
				<td class="t-b">
					<p><input type="radio" name="ctwlpt_timer_use_ms" value="yes" id="ctwlpt_timer_use_ms_1" <?php checked($ctwlpt_timer_use_ms,'yes') ?>/> <label for="ctwlpt_timer_use_ms_1">表示する（動作が重くなる可能性があります）</label></p>
					<p><input type="radio" name="ctwlpt_timer_use_ms" value="no" id="ctwlpt_timer_use_ms_2" <?php checked($ctwlpt_timer_use_ms,'no') ?>/> <label for="ctwlpt_timer_use_ms_2">表示しない</label></p>
				</td>
			</tr>
		</table>
	</div>
	
	<h2 style="margin-top:1em;padding:.5em;color:#fff;background:#666;border-radius:5px 5px 0px 0px;">【STEP 4】起点ページ設定</h2>
	<div style="padding:1em;border:1px solid #666;border-radius:0px 0px 5px 5px;">
		<table class="lptools-setting-table" style="width:100%">
			<tr class="ctwlpt_select_nouse_timer_triger">
				<td class="t-h">
					このページをステップメール連動タイマーの起点とするかどうか
					<div style="padding:1em;margin-top:1em;background:#eee;">このLPにアクセスしたとき、Cookieにアクセス日時を記録するかどうかを選択します。記録されたアクセス日時を、ステップメール連動タイマーで起点として利用します。<br />詳しい使い方は<a href="https://ctw-contents.com/ctp/lptools/member/faq/3595/">こちら</a>をご覧ください。</div>
				</td>
				<td class="t-b">
					<p><input type="radio" name="ctwlpt_use_timer_triger" value="no" id="ctwlpt_use_timer_triger_2" class="ctwlpt_use_timer_triger" <?php checked($ctwlpt_use_timer_triger,'no') ?>/> <label for="ctwlpt_use_timer_triger_2">ステップメール連動タイマーの起点としない</label></p>
					<p><input type="radio" name="ctwlpt_use_timer_triger" value="yes" id="ctwlpt_use_timer_triger_1" class="ctwlpt_use_timer_triger" <?php checked($ctwlpt_use_timer_triger,'yes') ?>/> <label for="ctwlpt_use_timer_triger_1">アクセス日時を残してステップメール連動タイマーの起点とする</label></p>
				</td>
			</tr>
			
			<tr class="ctwlpt_timer_select_trigger ctwlpt_select_use_timer_triger">
				<td class="t-h">
					アクセス日時を残すID
					<div style="padding:1em;margin-top:1em;background:#eee;">半角英数のみ利用できます。アクセス日時を残してステップメール連動タイマーの起点とするときと、ステップメール連動タイマー利用をするときは、同じIDにしてください。</div>
				</td>
				<td class="t-b">
					<p>ID：<input type="text" pattern="^[0-9A-Za-z]+$" name="ctwlpt_timer_trigger_key" id="ctwlpt_timer_trigger_key" value="<?php echo $ctwlpt_timer_trigger_key; ?>" placeholder="例：lptools_step_01"/></p>
					<p class="ctwlpt_select_nouse_timer_triger">アクセス日時のCookieを残す日数：<input type="number" name="ctwlpt_timer_trigger_expire" id="ctwlpt_timer_trigger_expire" value="<?php echo $ctwlpt_timer_trigger_expire; ?>" style="max-width:4em"/>日間</p>
				</td>
			</tr>
		</table>
	</div>
<?php
}

function lptools_optional_custom_fields() {
	global $post;
		
	$ctwlpt_lp_title	= get_post_meta( $post->ID,'ctwlpt_lp_title', true );
	if( empty($ctwlpt_lp_title) ) $ctwlpt_lp_title = '';
	
	$ctwlpt_enable_sp_br	= get_post_meta( $post->ID,'ctwlpt_enable_sp_br', true );
	if( empty($ctwlpt_enable_sp_br) ) $ctwlpt_enable_sp_br = 'no';
	
	$ctwlpt_use_siteicon	= get_post_meta( $post->ID,'ctwlpt_use_siteicon', true );
	if( empty($ctwlpt_use_siteicon) ) $ctwlpt_use_siteicon = 'yes';
	
	$ctwlpt_use_lazyload	= get_post_meta( $post->ID,'ctwlpt_use_lazyload', true );
	if( empty($ctwlpt_use_lazyload) ) $ctwlpt_use_lazyload = 'no';
	
	$ctwlpt_use_urlparams	= get_post_meta( $post->ID,'ctwlpt_use_urlparams', true );
	if( empty($ctwlpt_use_urlparams) ) $ctwlpt_use_urlparams = 'no';
	
	$ctwlpt_use_wphead	= get_post_meta( $post->ID,'ctwlpt_use_wphead', true );
	if( empty($ctwlpt_use_wphead) ) $ctwlpt_use_wphead = 'both';
	
	$ctwlpt_use_noindex	= get_post_meta( $post->ID,'ctwlpt_use_noindex', true );
	if( empty($ctwlpt_use_noindex) ) $ctwlpt_use_noindex = 'no';
	
	$ctwlpt_head	= get_post_meta( $post->ID,'ctwlpt_head', true );
	$ctwlpt_body	= get_post_meta( $post->ID,'ctwlpt_body', true );
	
	$ctwlpt_nouse_add_code_end_head	= get_post_meta( $post->ID,'ctwlpt_nouse_add_code_end_head', true );
	$ctwlpt_nouse_add_code_end_body	= get_post_meta( $post->ID,'ctwlpt_nouse_add_code_end_body', true );
?>
	<table id="lptools-optional-settings-table" class="lptools-setting-table" style="width:100%">
		<tr>
			<td class="t-h">
				LPのタイトル
				<div style="padding:1em;margin-top:1em;background:#eee;">投稿のタイトルとは別にLPのタイトルタグに出力するタイトルを設定できます。空欄の場合は、投稿のタイトルがタイトルタグに設定されます。</div>
			</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_lp_title" id="ctwlpt_lp_title" value="<?php echo $ctwlpt_lp_title; ?>" style="width:100%" /></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">
				このLPのスマホ改行を常に有効にする
				<div style="padding:1em;margin-top:1em;background:#eee;">チェックを入れるとブロックごとの「スマホで改行タグを有効にする」設定に関わらず、スマホ表示でも常に改行が有効になります。</div>
			</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_enable_sp_br" value="yes" id="ctwlpt_enable_sp_br_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_enable_sp_br,'yes') ?>/> <label for="ctwlpt_enable_sp_br_1">有効にする</label></p>
				<p><input type="radio" name="ctwlpt_enable_sp_br" value="no" id="ctwlpt_enable_sp_br_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_enable_sp_br,'no') ?>/> <label for="ctwlpt_enable_sp_br_2">無効にする（ブロックごとに選択する）</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">設定されているサイトアイコンを読み込む</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_siteicon" value="yes" id="ctwlpt_use_siteicon_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_siteicon,'yes') ?>/> <label for="ctwlpt_use_siteicon_1">読み込む</label></p>
				<p><input type="radio" name="ctwlpt_use_siteicon" value="no" id="ctwlpt_use_siteicon_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_siteicon,'no') ?>/> <label for="ctwlpt_use_siteicon_2">読み込まない</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">画像やiframeの遅延読み込みを利用するかどうか</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_lazyload" value="yes" id="ctwlpt_use_lazyload_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_lazyload,'yes') ?>/> <label for="ctwlpt_use_lazyload_1">利用する</label></p>
				<p><input type="radio" name="ctwlpt_use_lazyload" value="no" id="ctwlpt_use_lazyload_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_lazyload,'no') ?>/> <label for="ctwlpt_use_lazyload_2">利用しない</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">ボタン利用時に、URLのパラメータを引き継ぐかどうか</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_urlparams" value="yes" id="ctwlpt_use_urlparams_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_urlparams,'yes') ?>/> <label for="ctwlpt_use_urlparams_1">引き継ぐ</label></p>
				<p><input type="radio" name="ctwlpt_use_urlparams" value="no" id="ctwlpt_use_urlparams_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_urlparams,'no') ?>/> <label for="ctwlpt_use_urlparams_2">引き継がない</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">
				テーマやプラグインの機能を利用するかどうか
				<div style="padding:1em;margin-top:1em;background:#eee;">wp_headかwp_footer（または両方）を読み込むことで、テーマやその他プラグインの機能やブロックなどを使えるようになりますが、LPの表示が崩れたり、ページが重くなる可能性があります。<br />テーマによっては、使えないこともありますがご了承ください。</div>
			</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_wphead" value="no" id="ctwlpt_use_wphead_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_wphead,'no') ?>/> <label for="ctwlpt_use_wphead_1">テーマやプラグインの機能は利用しない（表示速度は最速となります）</label></p>
				<p><input type="radio" name="ctwlpt_use_wphead" value="both" id="ctwlpt_use_wphead_4" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_wphead,'both') ?>/> <label for="ctwlpt_use_wphead_4">テーマやプラグインの機能を利用する（表示速度が低下する恐れがあります）</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">
				このLPを検索結果に表示されないようにする
				<div style="padding:1em;margin-top:1em;background:#eee;">noindexタグを出力しますが、インデックスされないことを保証するものではありません。</div>
			</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_noindex" value="yes" id="ctwlpt_use_noindex_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_noindex,'yes') ?>/> <label for="ctwlpt_use_noindex_1">検索結果に表示されないようにする（noindexを出力する）</label></p>
				<p><input type="radio" name="ctwlpt_use_noindex" value="no" id="ctwlpt_use_noindex_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_noindex,'no') ?>/> <label for="ctwlpt_use_noindex_2">デフォルト（noindexを出力しない）</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">
				追加コード（head内に出力されます）
				<div style="padding:1em;margin-top:1em;background:#eee;">cssを直接追加する場合は、<?php echo htmlspecialchars('<style type="text/css" media="screen"></style>'); ?>タグが必要です。javascriptを直接追加する場合は、<?php echo htmlspecialchars('<script type="text/javascript"></script>'); ?>タグが必要です。</div>
			</td>
			<td class="t-b">
				<p><textarea name="ctwlpt_head" id="ctwlpt_head" cols="30" rows="10" style="padding:.5em;width:100%;"><?php echo $ctwlpt_head; ?></textarea></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">
				追加コード（body内に出力されます）
				<div style="padding:1em;margin-top:1em;background:#eee;">cssを直接追加する場合は、<?php echo htmlspecialchars('<style type="text/css" media="screen"></style>'); ?>タグが必要です。javascriptを直接追加する場合は、<?php echo htmlspecialchars('<script type="text/javascript"></script>'); ?>タグが必要です。</div>
			</td>
			<td class="t-b">
				<p><textarea name="ctwlpt_body" id="ctwlpt_body" cols="30" rows="10" style="padding:.5em;width:100%;"><?php echo $ctwlpt_body; ?></textarea></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">
				全体設定の一括コード追加（&lt;/head&gt;前）の対象から除外する
			</td>
			<td class="t-b">
				<p><input type="checkbox" name="ctwlpt_nouse_add_code_end_head" value="yes" id="ctwlpt_nouse_add_code_end_head" class="ctwlpt_timer_type" <?php checked($ctwlpt_nouse_add_code_end_head,'yes') ?>/> <label for="ctwlpt_nouse_add_code_end_head">一括コード追加（&lt;/head&gt;前）を出力しない</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">
				全体設定の一括コード追加（&lt;/body&gt;前）の対象から除外する
			</td>
			<td class="t-b">
				<p><input type="checkbox" name="ctwlpt_nouse_add_code_end_body" value="yes" id="ctwlpt_nouse_add_code_end_body" class="ctwlpt_timer_type" <?php checked($ctwlpt_nouse_add_code_end_body,'yes') ?>/> <label for="ctwlpt_nouse_add_code_end_body">一括コード追加（&lt;/body&gt;前）を出力しない</label></p>
			</td>
		</tr>
	</table>
<?php
}


function lptools_redirect_custom_fields() {
	global $post;
	
	$ctwlpt_use_redirect	= get_post_meta( $post->ID,'ctwlpt_use_redirect', true );
	if( empty($ctwlpt_use_redirect) ) $ctwlpt_use_redirect = 'no';
	
	$ctwlpt_redirect_url	= get_post_meta( $post->ID,'ctwlpt_redirect_url', true );
	if( empty($ctwlpt_redirect_url) ) $ctwlpt_redirect_url = '';
	
	$ctwlpt_redirect_sec	= get_post_meta( $post->ID,'ctwlpt_redirect_sec', true );
	if( empty($ctwlpt_redirect_sec) ) $ctwlpt_redirect_sec = 0;
?>
	<table class="lptools-setting-table" style="width:100%">	
		<tr>
			<td class="t-h">リダイレクトを有効にするかどうか</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_redirect" value="yes" id="ctwlpt_use_redirect_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_redirect,'yes') ?>/> <label for="ctwlpt_use_redirect_1">有効にする</label></p>
				<p><input type="radio" name="ctwlpt_use_redirect" value="no" id="ctwlpt_use_redirect_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_redirect,'no') ?>/> <label for="ctwlpt_use_redirect_2">無効にする</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">リダイレクト先</td>
			<td class="t-b">
				<p><input type="url" name="ctwlpt_redirect_url" id="ctwlpt_redirect_url" value="<?php echo htmlspecialchars_decode($ctwlpt_redirect_url); ?>" style="width:100%" /></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">リダイレクトまでの秒数</td>
			<td class="t-b">
				<p><input type="number" min="0" max="99" name="ctwlpt_redirect_sec" id="ctwlpt_redirect_sec" value="<?php echo $ctwlpt_redirect_sec; ?>" style="width:100%" /></p>
			</td>
		</tr>
	</table>
<?php
}


// --------------------------------------------
// 画像アップロード用のタグを出力
// --------------------------------------------
function lptools_generate_upload_image_tag($name, $value) {
?>
	<input name="<?php echo $name; ?>" type="text" value="<?php echo $value; ?>" />
	<input type="button" name="<?php echo $name; ?>_slect" value="選択" />
	<input type="button" name="<?php echo $name; ?>_clear" value="クリア" />
	<div id="<?php echo $name; ?>_thumbnail" class="uploded-thumbnail">
		<?php if ($value): ?>
		<img src="<?php echo $value; ?>" alt="選択中の画像">
		<?php endif ?>
	</div>
	<script type="text/javascript">
	(function ($) {
		var custom_uploader;
		$("input:button[name=<?php echo $name; ?>_slect]").click(function(e) {
			e.preventDefault();
			if (custom_uploader) {
				custom_uploader.open();
				return;
			}
			
			custom_uploader = wp.media({
				title: "画像を選択してください",
				library: {
					type: "image"
				},
				button: {
					text: "画像の選択"
				},
				
				multiple: false
			});
	
			custom_uploader.on("select", function() {
				var images = custom_uploader.state().get("selection");
				images.each(function(file){
					$("input:text[name=<?php echo $name; ?>]").val("");
					$("#<?php echo $name; ?>_thumbnail").empty();
					$("input:text[name=<?php echo $name; ?>]").val(file.attributes.sizes.full.url);
					$("#<?php echo $name; ?>_thumbnail").append('<img src="'+file.attributes.sizes.full.url+'" />');
				});
			});
		
			custom_uploader.open();
		});
	 
		$("input:button[name=<?php echo $name; ?>_clear]").click(function() {
			$("input:text[name=<?php echo $name; ?>]").val("");
			$("#<?php echo $name; ?>_thumbnail").empty();
		}); 
	})(jQuery);
	</script>
<?php
}


function lptools_ogp_custom_fields() {
	global $post;
	
	$ctwlpt_use_ogp	= get_post_meta( $post->ID,'ctwlpt_use_ogp', true );
	if( empty($ctwlpt_use_ogp) ) $ctwlpt_use_ogp = 'no';
	
	$ctwlpt_ogp_fb_title	= get_post_meta( $post->ID,'ctwlpt_ogp_fb_title', true );
	if( empty($ctwlpt_ogp_fb_title) ) $ctwlpt_ogp_fb_title = '';
	
	$ctwlpt_ogp_fb_description	= get_post_meta( $post->ID,'ctwlpt_ogp_fb_description', true );
	if( empty($ctwlpt_ogp_fb_description) ) $ctwlpt_ogp_fb_description = '';
	
	$ctwlpt_ogp_fb_sitename	= get_post_meta( $post->ID,'ctwlpt_ogp_fb_sitename', true );
	if( empty($ctwlpt_ogp_fb_sitename) ) $ctwlpt_ogp_fb_sitename = get_bloginfo('name');
	
	$ctwlpt_ogp_fb_img	= get_post_meta( $post->ID,'ctwlpt_ogp_fb_img', true );
	if( empty($ctwlpt_ogp_fb_img) ) $ctwlpt_ogp_fb_img = '';
	
	$ctwlpt_ogp_fb_appid	= get_post_meta( $post->ID,'ctwlpt_ogp_fb_appid', true );
	if( empty($ctwlpt_ogp_fb_appid) ) $ctwlpt_ogp_fb_appid = '';
	
	$ctwlpt_ogp_tw_card_type	= get_post_meta( $post->ID,'ctwlpt_ogp_tw_card_type', true );
	if( empty($ctwlpt_ogp_tw_card_type) ) $ctwlpt_ogp_tw_card_type = 'summary';
	
	$ctwlpt_ogp_tw_accountid	= get_post_meta( $post->ID,'ctwlpt_ogp_tw_accountid', true );
	if( empty($ctwlpt_ogp_tw_accountid) ) $ctwlpt_ogp_tw_accountid = '';
?>
	<table class="lptools-setting-table" style="width:100%">	
		<tr>
			<td class="t-h">OGP設定を有効にするかどうか</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_ogp" value="yes" id="ctwlpt_use_ogp_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_ogp,'yes') ?>/> <label for="ctwlpt_use_ogp_1">有効にする</label></p>
				<p><input type="radio" name="ctwlpt_use_ogp" value="no" id="ctwlpt_use_ogp_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_ogp,'no') ?>/> <label for="ctwlpt_use_ogp_2">無効にする</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">ページのタイトル</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_ogp_fb_title" id="ctwlpt_ogp_fb_title" value="<?php echo $ctwlpt_ogp_fb_title; ?>" style="width:100%" /></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">ページの説明</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_ogp_fb_description" id="ctwlpt_ogp_fb_description" value="<?php echo $ctwlpt_ogp_fb_description; ?>" style="width:100%" /></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">サイトの名前</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_ogp_fb_sitename" id="ctwlpt_ogp_fb_sitename" value="<?php echo $ctwlpt_ogp_fb_sitename; ?>" style="width:100%" /></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">画像</td>
			<td class="t-b">
				<p><?php lptools_generate_upload_image_tag('ctwlpt_ogp_fb_img', $ctwlpt_ogp_fb_img); ?></p>
				<p>推奨サイズ：1200×630</p>
			</td>
		</tr>
		<tr>
			<td class="t-h">FacebookアプリID（任意）</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_ogp_fb_appid" id="ctwlpt_ogp_fb_appid" value="<?php echo $ctwlpt_ogp_fb_appid; ?>" style="width:100%" /></p>
				<p>Facebookインサイトを利用する際に必要となります。<br />Facebookインサイトを利用しない場合は省略可能です。<a href="https://developers.facebook.com/docs/sharing/webmasters/?locale=ja_JP" target="_blank" rel="noopener noreferrer">詳細はこちら</a></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">Twitterカードタイプ（任意）</td>
			<td class="t-b">
				<p>
					<select name="ctwlpt_ogp_tw_card_type" id="ctwlpt_ogp_tw_card_type">
						<option value="summary" <?php selected($ctwlpt_ogp_tw_card_type,'summary'); ?>>サマリーカード</option>
						<option value="summary_large_image" <?php selected($ctwlpt_ogp_tw_card_type,'summary_large_image'); ?>>大型画像付きサマリーカード</option>
						<option value="photo" <?php selected($ctwlpt_ogp_tw_card_type,'photo'); ?>>画像</option>
						<option value="app" <?php selected($ctwlpt_ogp_tw_card_type,'app'); ?>>アプリ</option>
					</select>
				</p>
			</td>
		</tr>
		<tr>
			<td class="t-h">TwitterアカウントID（任意）</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_ogp_tw_accountid" id="ctwlpt_ogp_tw_accountid" value="<?php echo $ctwlpt_ogp_tw_accountid; ?>" style="width:100%" placeholder="例：@LPtools_CTW" /></p>
			</td>
		</tr>
	</table>
<?php
}



function lptools_footer_button_custom_fields() {
	global $post;

	$ctwlpt_use_footer_button		= get_post_meta( $post->ID,'ctwlpt_use_footer_button', true );
	if( empty($ctwlpt_use_footer_button) ) $ctwlpt_use_footer_button = 'no';
	
	$ctwlpt_footer_button_type		= get_post_meta( $post->ID,'ctwlpt_footer_button_type', true );
	if( empty($ctwlpt_footer_button_type) ) $ctwlpt_footer_button_type = 'text';
	
	$ctwlpt_footer_button_position	= get_post_meta( $post->ID,'ctwlpt_footer_button_position', true );
	if( empty($ctwlpt_footer_button_position) ) $ctwlpt_footer_button_position = '150';
	
	$ctwlpt_footer_button_img		= get_post_meta( $post->ID,'ctwlpt_footer_button_img', true );
	$ctwlpt_footer_button_text		= get_post_meta( $post->ID,'ctwlpt_footer_button_text', true );
	
	$ctwlpt_footer_button_bg_color	= get_post_meta( $post->ID,'ctwlpt_footer_button_bg_color', true );
	if( empty($ctwlpt_footer_button_bg_color) ) $ctwlpt_footer_button_bg_color = '#f5ce17';
	
	$ctwlpt_footer_button_tx_color	= get_post_meta( $post->ID,'ctwlpt_footer_button_tx_color', true );
	if( empty($ctwlpt_footer_button_tx_color) ) $ctwlpt_footer_button_tx_color = '#333333';
	
	$ctwlpt_footer_button_url		= get_post_meta( $post->ID,'ctwlpt_footer_button_url', true );
?>
	<script type="text/javascript">
		jQuery(document).ready(function($){
			$('.color-picker').wpColorPicker();
		});
	</script>
	<table id="lptools-footer-button-settings-table" class="lptools-setting-table" style="width:100%">	
		<tr>
			<td class="t-h">画面下に固定のボタンを設置する</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_use_footer_button" value="yes" id="ctwlpt_use_footer_button_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_footer_button,'yes') ?>/> <label for="ctwlpt_use_footer_button_1">設置する</label></p>
				<p><input type="radio" name="ctwlpt_use_footer_button" value="no" id="ctwlpt_use_footer_button_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_use_footer_button,'no') ?>/> <label for="ctwlpt_use_footer_button_2">設置しない</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">ボタンを表示する位置</td>
			<td class="t-b">
				<p><input type="number" min="0" max="9999999" name="ctwlpt_footer_button_position" id="ctwlpt_footer_button_position" value="<?php echo $ctwlpt_footer_button_position; ?>"/></p>
				<p>参考１：最初から表示 → 0<br />参考２：ファーストビューでは表示せず少しスクロールしたら表示 → 100〜150</p>
			</td>
		</tr>
		<tr>
			<td class="t-h">表示する固定のボタンの種類</td>
			<td class="t-b">
				<p><input type="radio" name="ctwlpt_footer_button_type" value="img" id="ctwlpt_footer_button_type_1" class="ctwlpt_timer_type" <?php checked($ctwlpt_footer_button_type,'img') ?>/> <label for="ctwlpt_footer_button_type_1">画像ボタンを利用</label></p>
				<p><input type="radio" name="ctwlpt_footer_button_type" value="text" id="ctwlpt_footer_button_type_2" class="ctwlpt_timer_type" <?php checked($ctwlpt_footer_button_type,'text') ?>/> <label for="ctwlpt_footer_button_type_2">テキストボタンを利用</label></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">ボタンの画像</td>
			<td class="t-b">
				<p><?php lptools_generate_upload_image_tag('ctwlpt_footer_button_img', $ctwlpt_footer_button_img); ?></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">ボタンのテキスト</td>
			<td class="t-b">
				<textarea name="ctwlpt_footer_button_text" id="ctwlpt_footer_button_text" cols="50" rows="5"><?php echo $ctwlpt_footer_button_text; ?></textarea>
			</td>
		</tr>
		<tr>
			<td class="t-h">ボタンの背景色</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_footer_button_bg_color" id="ctwlpt_footer_button_bg_color" class="color-picker" value="<?php echo $ctwlpt_footer_button_bg_color; ?>" /></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">ボタンの文字色</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_footer_button_tx_color" id="color_picker_2" class="color-picker" value="<?php echo $ctwlpt_footer_button_tx_color; ?>" /></p>
			</td>
		</tr>
		<tr>
			<td class="t-h">遷移先URL</td>
			<td class="t-b">
				<p><input type="text" name="ctwlpt_footer_button_url" id="ctwlpt_footer_button_url" value="<?php echo $ctwlpt_footer_button_url; ?>"/></p>
			</td>
		</tr>
	</table>
<?php
}

function lptools_color_palette_custom_fields() {
	global $post;

	$ctwlpt_color_palette = get_post_meta( $post->ID,'ctwlpt_color_palette', true );
	if ( empty( $ctwlpt_color_palette ) && $ctwlpt_color_palette != 0 ) $ctwlpt_color_palette = '';
?>
	<script type="text/javascript">
		jQuery(document).ready(function($){
			$('.color-picker').wpColorPicker();
		});
	</script>
	<table id="lptools-color-palette-settings-table" class="lptools-setting-table" style="width:100%">
		<tr>
			<td class="t-h">
				このLPで使うカラーパレットを選択
				<div style="padding:1em;margin-top:1em;background:#eee;">このLPで利用したいカラーパレットを選択してください。<br />カラーパレット選択後は、一度ページ設定を保存または更新をした後、ブラウザを更新してください。<br />カラーパレットのカスタマイズは<a href="<?php echo admin_url().'admin.php?page=ctwlpt_option_menu_color'; ?>">こちらのページ</a>から行えます。</div></td>
			<td class="t-b">
				<select name="ctwlpt_color_palette">
					<option value="">デフォルト</option>
					<?php
					$color_palette_titles = get_option( 'lptools_color_palette_titles' );
					foreach ( $color_palette_titles as $i => $title ) : ?>
					<?php if ( $title == '' ) continue; ?>
					<option value="<?php echo $i; ?>" <?php selected( $ctwlpt_color_palette, $i ) ?>><?php echo $title; ?></option>
					<?php endforeach; ?>
				</select>
			</td>
		</tr>
	</table>
<?php
}


// --------------------------------------------
// 設定カスタムフィールドの更新
// --------------------------------------------
function lptools_save_custom_fields( $post_id ) {
	$slug = get_page_template_slug( $post_id );
	
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
		return $post_id;
		
	if (!current_user_can('edit_post', $post_id))
		return $post_id;
	
	if (isset($_POST['action']) && $_POST['action'] == 'inline-save')
		return $post_id;
		
	$post_type = get_post_type( $post_id );
	
	if( $post_type == 'clp' || $post_type == 'lptools_template' || ( 'page' == $post_type && $slug == CTW_LPTOOLS_TEMPLATE_SLUG ) ) {
		
		if(isset($_POST['ctwlpt_use_timer_triger'])){
			update_post_meta($post_id, 'ctwlpt_use_timer_triger', $_POST['ctwlpt_use_timer_triger']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_timer_triger');
		}
		
		if(isset($_POST['ctwlpt_timer_trigger_key'])){
			update_post_meta($post_id, 'ctwlpt_timer_trigger_key', $_POST['ctwlpt_timer_trigger_key']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_trigger_key');
		}
		
		if(isset($_POST['ctwlpt_timer_trigger_read_key'])){
			update_post_meta($post_id, 'ctwlpt_timer_trigger_read_key', $_POST['ctwlpt_timer_trigger_read_key']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_trigger_read_key');
		}
		
		if(isset($_POST['ctwlpt_timer_trigger_day'])){
			update_post_meta($post_id, 'ctwlpt_timer_trigger_day', $_POST['ctwlpt_timer_trigger_day']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_trigger_day');
		}
		
		if(isset($_POST['ctwlpt_timer_trigger_hour'])){
			update_post_meta($post_id, 'ctwlpt_timer_trigger_hour', $_POST['ctwlpt_timer_trigger_hour']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_trigger_hour');
		}
		
		if(isset($_POST['ctwlpt_timer_trigger_min'])){
			update_post_meta($post_id, 'ctwlpt_timer_trigger_min', $_POST['ctwlpt_timer_trigger_min']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_trigger_min');
		}
		
		if(isset($_POST['ctwlpt_timer_trigger_expire'])){
			update_post_meta($post_id, 'ctwlpt_timer_trigger_expire', $_POST['ctwlpt_timer_trigger_expire']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_trigger_expire');
		}
		
		if(isset($_POST['ctwlpt_timer_type'])){
			update_post_meta($post_id, 'ctwlpt_timer_type', $_POST['ctwlpt_timer_type']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_type');
		}
		
		if(isset($_POST['ctwlpt_timer_access_times'])){
			update_post_meta($post_id, 'ctwlpt_timer_access_times', $_POST['ctwlpt_timer_access_times']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_access_times');
		}
		
		if(isset($_POST['ctwlpt_timer_redirect_url'])){
			update_post_meta($post_id, 'ctwlpt_timer_redirect_url', $_POST['ctwlpt_timer_redirect_url']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_redirect_url');
		}
		
		if(isset($_POST['ctwlpt_timer_end_word'])){
			update_post_meta($post_id, 'ctwlpt_timer_end_word', $_POST['ctwlpt_timer_end_word']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_end_word');
		}
		
		if(isset($_POST['ctwlpt_timer_use_s'])){
			update_post_meta($post_id, 'ctwlpt_timer_use_s', $_POST['ctwlpt_timer_use_s']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_use_s');
		}
		
		if(isset($_POST['ctwlpt_timer_use_ms'])){
			update_post_meta($post_id, 'ctwlpt_timer_use_ms', $_POST['ctwlpt_timer_use_ms']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_use_ms');
		}
		
		if(isset($_POST['ctwlpt_timer_countdown_date'])){
			update_post_meta($post_id, 'ctwlpt_timer_countdown_date', $_POST['ctwlpt_timer_countdown_date']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_countdown_date');
		}
		
		if(isset($_POST['ctwlpt_timer_limited_time'])){
			update_post_meta($post_id, 'ctwlpt_timer_limited_time', $_POST['ctwlpt_timer_limited_time']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_timer_limited_time');
		}
		
		if(isset($_POST['ctwlpt_lp_title'])){
			update_post_meta($post_id, 'ctwlpt_lp_title', $_POST['ctwlpt_lp_title']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_lp_title');
		}
		
		if(isset($_POST['ctwlpt_enable_sp_br'])){
			update_post_meta($post_id, 'ctwlpt_enable_sp_br', $_POST['ctwlpt_enable_sp_br']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_enable_sp_br');
		}
		
		if(isset($_POST['ctwlpt_use_siteicon'])){
			update_post_meta($post_id, 'ctwlpt_use_siteicon', $_POST['ctwlpt_use_siteicon']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_siteicon');
		}
		
		if(isset($_POST['ctwlpt_use_lazyload'])){
			update_post_meta($post_id, 'ctwlpt_use_lazyload', $_POST['ctwlpt_use_lazyload']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_lazyload');
		}
		
		if(isset($_POST['ctwlpt_use_urlparams'])){
			update_post_meta($post_id, 'ctwlpt_use_urlparams', $_POST['ctwlpt_use_urlparams']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_urlparams');
		}
		
		if(isset($_POST['ctwlpt_use_wphead'])){
			update_post_meta($post_id, 'ctwlpt_use_wphead', $_POST['ctwlpt_use_wphead']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_wphead');
		}
		
		if(isset($_POST['ctwlpt_use_noindex'])){
			update_post_meta($post_id, 'ctwlpt_use_noindex', $_POST['ctwlpt_use_noindex']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_noindex');
		}
		
		if(isset($_POST['ctwlpt_head'])){
			update_post_meta($post_id, 'ctwlpt_head', htmlspecialchars($_POST['ctwlpt_head']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_head');
		}
		
		if(isset($_POST['ctwlpt_body'])){
			update_post_meta($post_id, 'ctwlpt_body', htmlspecialchars($_POST['ctwlpt_body']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_body');
		}
		
		if(isset($_POST['ctwlpt_use_redirect'])){
			update_post_meta($post_id, 'ctwlpt_use_redirect', htmlspecialchars($_POST['ctwlpt_use_redirect']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_redirect');
		}
		
		if(isset($_POST['ctwlpt_redirect_url'])){
			update_post_meta($post_id, 'ctwlpt_redirect_url', htmlspecialchars($_POST['ctwlpt_redirect_url']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_redirect_url');
		}
		
		if(isset($_POST['ctwlpt_redirect_sec'])){
			update_post_meta($post_id, 'ctwlpt_redirect_sec', htmlspecialchars($_POST['ctwlpt_redirect_sec']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_redirect_sec');
		}
		
		if(isset($_POST['ctwlpt_use_footer_button'])){
			update_post_meta($post_id, 'ctwlpt_use_footer_button', htmlspecialchars($_POST['ctwlpt_use_footer_button']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_footer_button');
		}
		
		if(isset($_POST['ctwlpt_footer_button_type'])){
			update_post_meta($post_id, 'ctwlpt_footer_button_type', htmlspecialchars($_POST['ctwlpt_footer_button_type']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_footer_button_type');
		}
		
		if(isset($_POST['ctwlpt_footer_button_position'])){
			update_post_meta($post_id, 'ctwlpt_footer_button_position', htmlspecialchars($_POST['ctwlpt_footer_button_position']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_footer_button_position');
		}
		
		if(isset($_POST['ctwlpt_footer_button_img'])){
			update_post_meta($post_id, 'ctwlpt_footer_button_img', htmlspecialchars($_POST['ctwlpt_footer_button_img']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_footer_button_img');
		}
		
		if(isset($_POST['ctwlpt_footer_button_text'])){
			update_post_meta($post_id, 'ctwlpt_footer_button_text', htmlspecialchars($_POST['ctwlpt_footer_button_text']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_footer_button_text');
		}
		
		if(isset($_POST['ctwlpt_footer_button_bg_color'])){
			update_post_meta($post_id, 'ctwlpt_footer_button_bg_color', htmlspecialchars($_POST['ctwlpt_footer_button_bg_color']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_footer_button_bg_color');
		}
		
		if(isset($_POST['ctwlpt_footer_button_tx_color'])){
			update_post_meta($post_id, 'ctwlpt_footer_button_tx_color', htmlspecialchars($_POST['ctwlpt_footer_button_tx_color']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_footer_button_tx_color');
		}
		
		if(isset($_POST['ctwlpt_footer_button_url'])){
			update_post_meta($post_id, 'ctwlpt_footer_button_url', htmlspecialchars($_POST['ctwlpt_footer_button_url']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_footer_button_url');
		}
		
		if(isset($_POST['ctwlpt_nouse_add_code_end_head'])){
			update_post_meta($post_id, 'ctwlpt_nouse_add_code_end_head', htmlspecialchars($_POST['ctwlpt_nouse_add_code_end_head']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_nouse_add_code_end_head');
		}
		
		if(isset($_POST['ctwlpt_nouse_add_code_end_body'])){
			update_post_meta($post_id, 'ctwlpt_nouse_add_code_end_body', htmlspecialchars($_POST['ctwlpt_nouse_add_code_end_body']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_nouse_add_code_end_body');
		}

		if(isset($_POST['ctwlpt_color_palette'])){
			update_post_meta($post_id, 'ctwlpt_color_palette', $_POST['ctwlpt_color_palette']);
		} else {
			delete_post_meta($post_id, 'ctwlpt_color_palette');
		}
		
		// OGP
		if(isset($_POST['ctwlpt_use_ogp'])){
			update_post_meta($post_id, 'ctwlpt_use_ogp', htmlspecialchars($_POST['ctwlpt_use_ogp']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_use_ogp');
		}
		
		if(isset($_POST['ctwlpt_ogp_fb_title'])){
			update_post_meta($post_id, 'ctwlpt_ogp_fb_title', htmlspecialchars($_POST['ctwlpt_ogp_fb_title']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_ogp_fb_title');
		}
		
		if(isset($_POST['ctwlpt_ogp_fb_description'])){
			update_post_meta($post_id, 'ctwlpt_ogp_fb_description', htmlspecialchars($_POST['ctwlpt_ogp_fb_description']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_ogp_fb_description');
		}
		
		if(isset($_POST['ctwlpt_ogp_fb_sitename'])){
			update_post_meta($post_id, 'ctwlpt_ogp_fb_sitename', htmlspecialchars($_POST['ctwlpt_ogp_fb_sitename']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_ogp_fb_sitename');
		}
		
		if(isset($_POST['ctwlpt_ogp_fb_img'])){
			update_post_meta($post_id, 'ctwlpt_ogp_fb_img', htmlspecialchars($_POST['ctwlpt_ogp_fb_img']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_ogp_fb_img');
		}
		
		if(isset($_POST['ctwlpt_ogp_fb_appid'])){
			update_post_meta($post_id, 'ctwlpt_ogp_fb_appid', htmlspecialchars($_POST['ctwlpt_ogp_fb_appid']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_ogp_fb_appid');
		}
		
		if(isset($_POST['ctwlpt_ogp_tw_card_type'])){
			update_post_meta($post_id, 'ctwlpt_ogp_tw_card_type', htmlspecialchars($_POST['ctwlpt_ogp_tw_card_type']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_ogp_tw_card_type');
		}
		
		if(isset($_POST['ctwlpt_ogp_tw_accountid'])){
			update_post_meta($post_id, 'ctwlpt_ogp_tw_accountid', htmlspecialchars($_POST['ctwlpt_ogp_tw_accountid']));
		} else {
			delete_post_meta($post_id, 'ctwlpt_ogp_tw_accountid');
		}
	}
}
add_action('save_post', 'lptools_save_custom_fields');


// --------------------------------------------
// 指定のURLに、現在表示しているURLのパラメータを追加
// --------------------------------------------
function lptools_add_url_param( $redirect_url ){
	
	$parse_redirect_url = parse_url($redirect_url);
	if( empty($parse_redirect_url['host']) ) {
		return $redirect_url;
	}
	
	$lp_query = $_SERVER["QUERY_STRING"];
	if( empty($lp_query) ) {
		return $redirect_url;
	}	
	
	if( empty($parse_redirect_url['query']) ) {
		$return_url = $redirect_url.'?'.$lp_query;
	} else {
		$return_url = $redirect_url.'&'.$lp_query;
	}
	
	return $return_url;
	
}

// --------------------------------------------
// 遅延読み込み中用の置換
// --------------------------------------------
function lptools_change_the_content($the_content) {
	
	$post_id = get_the_id();
	$ctwlpt_use_lazyload = get_post_meta( $post_id,'ctwlpt_use_lazyload', true );
	$post_type = get_post_type( $post_id );
	global $post;
	$slug = get_page_template_slug( $post->ID );
	
	// 設定が no のとき、または、投稿タイプがclp以外かつLPtoolsテンプレート以外のときは置換しない
	if( (!empty($ctwlpt_use_lazyload) && $ctwlpt_use_lazyload == 'no') || ( $post_type != 'clp' && $post_type != 'lptools_template' && $slug != CTW_LPTOOLS_TEMPLATE_SLUG ) ) {
		return $the_content;
	}
	
	$the_content = str_replace('src="','data-src="',$the_content);
	$the_content = preg_replace( '/style="background-image:url\((.*?)\)[;]?([^"]*?)"/', 'data-background-image="$1" style="$2"', $the_content );
	
	return $the_content;
}
add_filter('the_content','lptools_change_the_content');

// ------------------------------------------------------------
// カスタムタクソノミーで絞り込み
// ------------------------------------------------------------
add_action( 'restrict_manage_posts', 'lptools_add_custom_taxonomies_term_filter' );
function lptools_add_custom_taxonomies_term_filter() {
	global $post_type;
	if ( $post_type == 'clp' ) {
		$taxonomy = 'clp_category';
		wp_dropdown_categories( array(
		'show_option_all' => '用途で絞り込み',
		'orderby' => 'name',
		'selected' => get_query_var( $taxonomy ),
		'hide_empty' => 0,
		'name' => $taxonomy,
		'taxonomy' => $taxonomy,
		'value_field' => 'slug',
		) );
	}
}
