<?php
if(!defined('ABSPATH')) exit;

// -----------------------------------------------------------------------
// 指定のidと一致するCookieを取得する。最初のアクセス時、トリガーページの指定があればCookieを残す。
// 
// $timer_id	：Cookieのkey
// $trigger_type：yesなら初回アクセス時にCookieを残す
// $expires		：Cookieを残すときの有効期限を◯日で指定（デフォルトは30日）
// -----------------------------------------------------------------------
function lptools_get_cookie_date( $timer_id, $trigger_type = 'no', $expires_day = 30 ) {
	
	$first_access_date	= '';
	$use_cookie			= false;
	$now_date	= date_i18n('Y/m/d H:i:s');
	
	// 有効期限が1以下なら1にする
	if( $expires_day < 1 ) {
		$expires_day = 1;
	}
	
	// トリガー指定がおかしいとき（0でも1でもないとき）はトリガー指定をしない
	if( $trigger_type != 'no' && $trigger_type != 'yes' ) {
		$trigger_type = 'no';
	}
	
	// 有効期限を決める
	$expires = time()+60*60*24*$expires_day;
	
	// 指定したCookieがあるときは最初のアクセス日を読み込む
	if( !empty($_COOKIE[$timer_id]) ) {
		$first_access_date	= $_COOKIE[$timer_id];
		$use_cookie			= true;
	}

	// 最初のアクセス日がないとき、かつトリガーページとして指定されているとき、新規のCookieとしてセットする
	if( !$first_access_date && $trigger_type == 'yes' ) {
		$first_access_date	= $now_date;
		setcookie( $timer_id, $now_date, $expires, '/' );
	}
	
	return array($use_cookie,$first_access_date);
}



// -----------------------------------------------------------------------
// 期限を設定する。
// 
// $limit_day				：トリガーページのアクセスから◯日後
// $$limit_hour				：トリガーページのアクセスから◯時
// $limit_minute			：トリガーページのアクセスから◯分
// $limit_date_string		：現在から◯日後の◯時◯分の数字（２ケタずつハイフンで区切る。例：現在から２日後の19時半のとき→?tid=02-19-30）
//
// $first_access_cookie		：最初のアクセス日
// $use_cookie				：Cookieを利用しているかどうか
// -----------------------------------------------------------------------
function lptools_set_limit_date( $limit_day, $limit_hour, $limit_minute, $limit_date_string, $first_access_cookie, $use_cookie = true ) {
	// 期限設定がないときデフォルトをセット（0日後の19時）
	if( !$limit_day ) $limit_day 		= 0;
	if( !$limit_hour ) $limit_hour		= 19;
	if( !$limit_minute ) $limit_minute	= 0;
	
	// 最初のアクセス日が空欄なら現在の日時をセット
	if( !$first_access_cookie ) {
		$first_access_cookie = date_i18n('Y/m/d H:i:s');
	}
	
	// Cookieから日時が読み込まれていなければ、「Cookieがないときの期限」を利用
	if( $use_cookie === false ) {
		
		// 文字列をハイフンで区切り、数値に変換
		$limit_date_string	= explode('-', $limit_date_string);
		$limit_day 		= (int)$limit_date_string[0];
		$limit_hour		= (int)$limit_date_string[1];
		$limit_minute	= (int)$limit_date_string[2];
	}
	
	
	$limit_time = mktime( $limit_hour, $limit_minute, 0, date_i18n('m',strtotime($first_access_cookie)), date_i18n('d',strtotime($first_access_cookie)) + $limit_day, date_i18n('Y',strtotime($first_access_cookie)) );
	
	return date('Y/m/d H:i:s',$limit_time);
}



// -----------------------------------------------------------------------
// 期限を取得する。
// 
// $post_id			：記事ID
// $$timer_id		：$timer_id：Cookieのkey
// $trigger_type	：yesなら初回アクセス時にCookieを残す
// $expires			：Cookieを残すときの有効期限を◯日で指定（デフォルトは30日）
// -----------------------------------------------------------------------
function lptools_get_limit_date( $post_id, $timer_id, $trigger_type = 'no', $expires_day = 30 ) {
	
	// 記事IDがないとき終了
	if( empty($post_id) ) return false;
	
	// 設定を取得
	$limit_day	= get_post_meta( $post_id,'ctwlpt_timer_trigger_day', true );
	$limit_hour	= get_post_meta( $post_id,'ctwlpt_timer_trigger_hour', true );
	$limit_minute	= get_post_meta( $post_id,'ctwlpt_timer_trigger_min', true );
	
	// Cookieがないときの期限をURLから取得。ないときはデフォルトをセット
	$limit_date_string 		= ( empty($_GET['tid']) ) ? str_pad($limit_day, 2, 0, STR_PAD_LEFT).'-'.str_pad($limit_hour, 2, 0, STR_PAD_LEFT).'-'.str_pad($limit_minute, 2, 0, STR_PAD_LEFT) : $_GET['tid'];
	
	// Cookieからトリガーページのアクセス日時を取得
	$first_access_cookie	= lptools_get_cookie_date( $timer_id, $trigger_type, $expires_day );
	
	// アクセス日時から期限をセット
	$limit_date				= lptools_set_limit_date( $limit_day, $limit_hour, $limit_minute, $limit_date_string, $first_access_cookie[1], $first_access_cookie[0] );
	
	return $limit_date;
}